summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/rp2c33_snd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/rp2c33_snd.cpp')
-rw-r--r--src/devices/sound/rp2c33_snd.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/rp2c33_snd.cpp b/src/devices/sound/rp2c33_snd.cpp
index 15446374ac1..57e60cf9fb5 100644
--- a/src/devices/sound/rp2c33_snd.cpp
+++ b/src/devices/sound/rp2c33_snd.cpp
@@ -56,7 +56,7 @@ void rp2c33_sound_device::device_start()
for (int i = 0; i < 4; i++)
m_mvol_table[i] = int((65536.0 / (32.0 * 64.0)) * 2.0 / double(i + 2));
- m_stream = machine().sound().stream_alloc(*this, 0, 1, clock());
+ m_stream = stream_alloc_legacy(0, 1, clock());
// save states
save_item(NAME(m_regs));
@@ -218,10 +218,10 @@ void rp2c33_sound_device::write(offs_t offset, u8 data)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void rp2c33_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void rp2c33_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
for (int i = 0; i < samples; i++)
{
@@ -218,10 +218,10 @@ void rp2c33_sound_device::write(offs_t offset, u8 data)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------